<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * Admin menu class
 */
class WCSS_Admin_Init {

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );

		// Shared cart list screen options.
		add_action( 'load-woo-cart-share_page_woocommerce-cart-share_shared-cart', array( 'WCSS_Admin_Shared_Cart_Table', 'add_screen_option' ) );
		add_filter( 'set-screen-option', array( 'WCSS_Admin_Shared_Cart_Table', 'set_screen_option' ), 10, 3 );

		// Saved cart list screen options.
		add_action( 'load-woo-cart-share_page_woocommerce-cart-share_saved-cart', array( 'WCSS_Admin_Saved_Cart_Table', 'add_screen_option' ) );
		add_filter( 'set-screen-option', array( 'WCSS_Admin_Saved_Cart_Table', 'set_screen_option' ), 10, 3 );

	}

	/**
	 * Add admin meni
	 */
	public function admin_menu() {
		add_menu_page(
			esc_html__( 'Woo Cart Share', 'woo-cart-share' ),
			esc_html__( 'Woo Cart Share', 'woo-cart-share' ),
			'manage_options',
			'woocommerce-cart-share',
			array( $this, 'admin_setting_page' ),
			'dashicons-cart',
			58
		);
		add_submenu_page(
			'woocommerce-cart-share',
			esc_html__( 'Shared Cart', 'woo-cart-share' ),
			esc_html__( 'Shared Cart', 'woo-cart-share' ),
			'manage_options',
			'woocommerce-cart-share_shared-cart',
			array( $this, 'admin_shared_cart_page' )
		);
		add_submenu_page(
			'woocommerce-cart-share',
			esc_html__( 'Saved Cart', 'woo-cart-share' ),
			esc_html__( 'Saved Cart', 'woo-cart-share' ),
			'manage_options',
			'woocommerce-cart-share_saved-cart',
			array( $this, 'admin_saved_cart_page' )
		);
		add_submenu_page(
			'woocommerce-cart-share',
			esc_html__( 'Plugin Support', 'woo-cart-share' ),
			esc_html__( 'Plugin Support', 'woo-cart-share' ),
			'manage_options',
			'woocommerce-cart-share_share-support',
			array( $this, 'admin_plugin_support_page' )
		);
		add_submenu_page(
			'woocommerce-cart-share',
			esc_html__( 'Documentation', 'woo-cart-share' ),
			esc_html__( 'Documentation', 'woo-cart-share' ),
			'manage_options',
			'woocommerce-cart-share_documentation',
			array( $this, 'admin_documentation_page' )
		);
	}

	/**
	 * Admin setting main page
	 */
	public function admin_setting_page() {
		require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-settings-page.php';
	}

	/**
	 * Admin saved cart list and view page.
	 *
	 * @since 1.9.0
	 */
	public function admin_shared_cart_page() {

		if ( isset( $_GET['page'] ) && 'woocommerce-cart-share_shared-cart' === $_GET['page'] && isset( $_GET['cart_key'] ) ) {
			$shared_cart = wcss_get_shared_cart( $_GET['cart_key'] );
			$saved_cart  = wcss_get_saved_cart( $_GET['cart_key'] );

			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-cart-view.php';
		} else {
			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-shared-cart-list.php';
		}
	}
	/**
	 * Admin saved cart list and view page.
	 */
	public function admin_saved_cart_page() {

		if ( isset( $_GET['page'] ) && 'woocommerce-cart-share_saved-cart' === $_GET['page'] && isset( $_GET['cart_key'] ) ) {
			$shared_cart = wcss_get_shared_cart( $_GET['cart_key'] );
			$saved_cart  = wcss_get_saved_cart( $_GET['cart_key'] );

			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-cart-view.php';
		} else {
			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-saved-cart-list.php';
		}
	}

	/**
	 * Admin plugin support page.
	 */
	public function admin_plugin_support_page() {
		require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-support.php';
	}

	/**
	 * Documentation page.
	 *
	 * @since 1.8.3
	 */
	public function admin_documentation_page() {
		?>
		<div class="wrap">
			<iframe src="//docs.wecreativez.com/document/woocommerce-cart-share-and-save/"
				frameborder="0"
				scrolling="yes"
				width="100%"
				height="800">
			</iframe>
		</div>
		<?php
	}
}

$wcss_admin_init = new WCSS_Admin_Init();
