<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * Plugin install class
 */
class WCSS_Install {

	/**
	 * Plugin install.
	 */
	public static function install() {

		do_action( 'wcss_before_install' );

		self::create_tables();
		self::register_settings();

		do_action( 'wcss_after_install' );

		// Add custom rewrite rules.
		self::add_rewrite_rule();

		// Flush WP rewrite rules.
		flush_rewrite_rules();

		// update current version.
		update_option( 'wcss_version', WCSS_PLUGIN_VER );
	}

	/**
	 * Register plugin settings.
	 *
	 * @return void
	 */
	public static function register_settings() {
		// Load settings.
		require_once WCSS_PLUGIN_PATH . 'includes/class-wcss-settings.php';

		WCSS_Settings::add_options();
	}

	public static function create_tables() {
		global $wpdb;

		require_once ABSPATH . 'wp-admin/includes/upgrade.php';

		$tables  = array();
		$collate = $wpdb->get_charset_collate();

		$tables['wcss_shared_cart'] = "CREATE TABLE {$wpdb->prefix}wcss_shared_cart (
			`id` BIGINT(20) NOT NULL AUTO_INCREMENT ,
			`cart_key` VARCHAR(32) NOT NULL ,
			`cart_value` LONGTEXT NOT NULL ,
			`cart_shared_by` BIGINT(20) NOT NULL DEFAULT '0' ,
			`cart_retrieved` BIGINT(20) NOT NULL ,
			`cart_retrieved_time` DATETIME DEFAULT NULL ,
			`cart_created` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00' ,
			PRIMARY KEY (`id`)
		) $collate;";

		/**
		 * Add 'Shared cart meta' table.
		 *
		 * @since 1.8.5
		 */
		$tables['wcss_shared_cart_meta'] = "CREATE TABLE {$wpdb->prefix}wcss_shared_cart_meta (
			`id` BIGINT NOT NULL AUTO_INCREMENT ,
			`cart_key` VARCHAR(32) NOT NULL ,
			`meta_key` VARCHAR(255) NOT NULL ,
			`meta_value` LONGTEXT NOT NULL ,
			PRIMARY KEY (`id`)
		) $collate;";

		$tables['wcss_saved_cart'] = "CREATE TABLE {$wpdb->prefix}wcss_saved_cart (
			`id` BIGINT(20) NOT NULL AUTO_INCREMENT ,
			`user_id` BIGINT(20) NOT NULL ,
			`cart_name` VARCHAR(128) DEFAULT NULL ,
			`cart_key` VARCHAR(32) NOT NULL ,
			`cart_saved` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00' ,
			PRIMARY KEY (`id`)
		) $collate;";

		foreach ( $tables as $table => $sql ) {
			if ( ! $wpdb->get_var( "SHOW TABLES LIKE '{$wpdb->prefix}{$table}'" ) ) {
				dbDelta( $sql );
			}
		}
	}

	/**
	 * Add plugin rewrite rule while plugin installing.
	 */
	public static function add_rewrite_rule() {
		// Get base slug
		$base_slug       = get_option( 'wcss_base_slug' );
		$my_account_slug = get_option( 'wcss_my_account_tab_slug' );

		// Add rewrite rule for plugin
		add_rewrite_rule( '^(' . $base_slug . ')/([^/]*)/?', 'index.php?wcss_share_cart=$matches[2]', 'top' );
		add_rewrite_endpoint( $my_account_slug, EP_ROOT | EP_PAGES );
	}

	/**
	 * array_merge_recursive does indeed merge arrays, but it converts values with duplicate
	 * keys to arrays rather than overwriting the value in the first array with the duplicate
	 * value in the second array, as array_merge does. I.e., with array_merge_recursive,
	 * this happens (documented behavior):
	 *
	 * @param array $array1
	 * @param array $array2
	 *
	 * @return array
	 */
	protected static function array_merge_recursive_distinct( $array1 = array(), $array2 = array() ) {
		$merged = $array1;
		foreach ( $array2 as $key => &$value ) {
			if ( is_array( $value ) && isset( $merged[ $key ] ) && is_array( $merged[ $key ] ) ) {
				$merged[ $key ] = self::array_merge_recursive_distinct( $merged[ $key ], $value );
			} else {
				$merged[ $key ] = $value;
			}
		}
		return $merged;
	}
}
