<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;


class WCSS_Popup {

	public function __construct() {
		// If current user has no access to share the cart then do nothing.
		if ( wcss_currnet_role_has_access() !== true ) {
			return;
		}

		$button_location = get_option( 'wcss_trigger_button_location' );

		// Add share cart button on cart page
		if ( 'before_checkout_btn' === $button_location ) {
			add_action( 'woocommerce_proceed_to_checkout', array( $this, 'display_share_button' ) );
		} elseif ( 'after_checkout_btn' === $button_location ) {
			add_action( 'woocommerce_after_cart_totals', array( $this, 'display_share_button' ) );
		} elseif ( 'with_apply_coupon' === $button_location ) {
			add_action( 'woocommerce_cart_coupon', array( $this, 'display_share_button' ) );
		} elseif ( 'before_cart_table' === $button_location ) {
			add_action( 'woocommerce_before_cart_table', array( $this, 'display_share_button' ) );
		} elseif ( 'after_cart_table' === $button_location ) {
			add_action( 'woocommerce_after_cart_table', array( $this, 'display_share_button' ) );
		} elseif ( 'cart_collaterals' === $button_location ) {
			add_action( 'woocommerce_cart_collaterals', array( $this, 'display_share_button' ) );
		} elseif ( 'before_cart_totals' === $button_location ) {
			add_action( 'woocommerce_before_cart_totals', array( $this, 'display_share_button' ) );
		}

		add_action( 'wp_footer', array( $this, 'display_popup' ) );
	}

	/**
	 * Output popup.
	 */
	public function display_popup() {
		wcss_get_template( 'popup.php' );
	}

	/**
	 * Output cart share button.
	 */
	public function display_share_button() {
		$buttons_status = get_option( 'wcss_trigger_buttons_status', array() );
		$buttons        = array();

		if ( isset( $buttons_status['share_cart'] ) && 'yes' === $buttons_status['share_cart'] ) {
			$buttons[] = sprintf( "<button class='button wcss-btn' data-wcss-popup-open>%s</button>", esc_html( get_option( 'wcss_share_cart_button_text' ) ) );
		}

		if ( isset( $buttons_status['save_cart'] ) && 'yes' === $buttons_status['save_cart'] && 'yes' === get_option( 'wcss_user_can_save_cart' ) ) {
			$buttons[] = sprintf( "<button class='button wcss-btn' data-wcss-save-cart-btn>%s</button>", esc_html( get_option( 'wcss_save_cart_button_text' ) ) );
		}

		if ( isset( $buttons_status['email_cart'] ) && 'yes' === $buttons_status['email_cart'] ) {
			$buttons[] = sprintf( "<button class='button wcss-btn' data-wcss-email-cart-btn>%s</button>", esc_html( get_option( 'wcss_email_cart_button_text' ) ) );
		}

		if ( isset( $buttons_status['print_cart'] ) && 'yes' === $buttons_status['print_cart'] ) {
			$buttons[] = sprintf( "<button class='button wcss-btn' data-wcss-print-cart-btn data-wcss-print-cart-btn>%s</button>", esc_html( get_option( 'wcss_print_cart_button_text' ) ) );
		}

		/**
		 * Trigger buttons filter.
		 *
		 * @since 1.8.3
		 *
		 * @param array $buttons    Buttons array.
		 */
		$buttons = apply_filters( 'wcss_trigger_buttons', $buttons );

		foreach ( $buttons as $button ) {
			echo wp_kses_post( $button );
		}
	}

} // end of WCSS_Popup

$wcss_popup = new WCSS_Popup();
