<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Legacy shared cart.
 *
 * Legacy and deprecated functions are here to keep the WCSS_Shared_Cart class clean.
 * This class will be removed in future versions.
 *
 */
abstract class WCSS_Legacy_Shared_Cart {

	/**
	 * Contains the shared cart table name.
	 *
	 * @var string Shared cart table name.
	 */
	private $table_name;

	/**
	 * Class constructor.
	 */
	public function __construct() {
		global $wpdb;

		$this->table_name = $wpdb->prefix . 'wcss_shared_cart';
	}

	/**
	 * Insert data into shared cart table.
	 *
	 * @param string $cart_key       Shared cart key.
	 * @param array  $cart_value     Shared cart value.
	 * @param int    $cart_retrieved Shared cart retrieved count.
	 * @param string $cart_created   Shared cart created time.
	 *
	 * @return int return current inserted ID
	 */
	public function insert( $cart_key, $cart_value = array(), $cart_retrieved = '', $cart_created = '' ) {
		global $wpdb;

		if ( ! $cart_retrieved ) {
			$cart_retrieved = 0;
		}
		if ( ! $cart_created ) {
			$cart_created = wcss_current_time();
		}
		if ( $this->is_cart_exist( $cart_key ) ) {
			return false;
		}

		return $wpdb->insert(
			$this->table_name,
			array(
				'cart_key'       => $cart_key,
				'cart_value'     => maybe_serialize( $cart_value ),
				'cart_shared_by' => get_current_user_id(),
				'cart_retrieved' => $cart_retrieved,
				'cart_created'   => $cart_created,
			),
			array(
				'%s',
				'%s',
				'%d',
				'%d',
				'%s',
			)
		);
	}

	/**
	 * Delete all the rows and data and make shared cart table empty.
	 *
	 * @return bool true if success, false otherwise.
	 */
	public function truncate() {
		global $wpdb;
		return $wpdb->query( "TRUNCATE TABLE {$this->table_name}" );
	}

	/**
	 * Get numbers of retrieved shared cart.
	 *
	 * @param string $cart_key Shared cart key.
	 * @return int Number of retrieved shared cart.
	 */
	public function get_cart_retrieved( $cart_key ) {
		global $wpdb;

		return $wpdb->get_var(
			$wpdb->prepare(
				"SELECT cart_retrieved
				FROM {$this->table_name}
				WHERE cart_key = %s",
				$cart_key
			)
		);
	}

	/**
	 * Get shared cart retrieved time.
	 *
	 * @param string $cart_key Shared cart key.
	 * @return string Shared cart retrieved time.
	 */
	public function get_cart_retrieved_time( $cart_key ) {
		global $wpdb;

		return $wpdb->get_var(
			$wpdb->prepare(
				"SELECT cart_retrieved_time
				FROM {$this->table_name}
				WHERE cart_key = %s",
				$cart_key
			)
		);
	}

	/**
	 * Get shared cart data.
	 *
	 * @param string $cart_key Shared cart key.
	 * @param string $column   Name of the column from shared cart database.
	 * @return mixed Return data from shared cart database.
	 */
	public function get_shared_cart_data( $cart_key, $column ) {
		if ( ! $column ) {
			return false;
		}

		global $wpdb;

		$data = $wpdb->get_var(
			$wpdb->prepare(
				"SELECT $column
				FROM {$this->table_name}
				WHERE cart_key = %s",
				$cart_key
			)
		);

		return maybe_unserialize( $data );
	}

	/**
	 * Delete shared cart by cart key.
	 *
	 * @param string $cart_key Shared cart key.
	 * @return bool true if shared cart deleted, false if not.
	 */
	public function delete_cart( $cart_key ) {
		global $wpdb;

		// Delete shared cart metas.
		wcss_delete_shared_cart_meta( $cart_key );

		$delete = $wpdb->delete(
			$this->table_name,
			array( 'cart_key' => $cart_key ),
			array( '%s' )
		);

		return $delete ? true : false;
	}

	/**
	 * Check if shared cart key exist.
	 *
	 * @param string $cart_key Shared cart key.
	 * @return bool true if shared cart exist, false if not.
	 */
	public function is_cart_exist( $cart_key ) {
		global $wpdb;

		$is_exists = $wpdb->get_var(
			$wpdb->prepare(
				"SELECT id
				FROM {$this->table_name}
				WHERE cart_key = %s",
				$cart_key
			)
		);

		return $is_exists ? true : false;
	}

}
